@@ -1,5 +1,4 @@
 # Author: Jacob van Etten jacobvanetten@yahoo.com
-# International Rice Research Institute
 # Date :  January 2009
 # Version 0.9
 # Licence GPL v3
@@ -17,19 +16,28 @@
 
 .cs <- function(a,b) {
 	aRep <- rep(a,times=length(b))
-	out <- cbind(aRep,as.integer(aRep+rep(b,each=length(a))),deparse.level=0)
-	return(out)
+	cbind(aRep,as.integer(aRep+rep(b,each=length(a))),deparse.level=0)
 }
 
 
-adjacency <- function(raster, fromCells, toCells, directions) {
 
-	outerMeridianConnect <- .isGlobalLonLat(raster)
 
-	if (directions=="Bishop") { return(.adjBishop(raster, fromCells, toCells, outerMeridianConnect)) }
+adjacency <- function(x, fromCells, toCells, directions) {
 
-	nCols <- ncol(raster)
-	nCells <- ncell(raster)
+	if (is.character(directions)) { directions <- tolower(directions) }
+	stopifnot(directions %in% c(4,8,16) | directions=='bishop')
+
+	x <- raster(x)
+
+	outerMeridianConnect <- .isGlobalLonLat(x)
+	
+	if (directions=="bishop") { 
+		return(.adjBishop(x, fromCells, toCells, outerMeridianConnect)) 
+	}
+
+	
+	nCols <- ncol(x)
+	nCells <- ncell(x)
 	
 	left <- seq(nCols+1,(nCells-2*nCols+1),by=nCols) 
 	right <- seq(2*nCols,nCells-nCols,by=nCols)
@@ -63,8 +71,7 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 	lowerrightFromToRook <- .cs(fromCellLowerright,rook[c(2,4)])
 	fromto1 <- rbind(coreFromToRook,upperFromToRook,lowerFromToRook,leftFromToRook,rightFromToRook,upperleftFromToRook,upperrightFromToRook,lowerleftFromToRook,lowerrightFromToRook)
 	
-	if (outerMeridianConnect) 
-	{
+	if (outerMeridianConnect) {
 		meridianFromLeft <- rbind(
 			cbind(fromCellsLeft,as.integer(fromCellsLeft+nCols-1)),
 			cbind(fromCellUpperleft,as.integer(fromCellUpperleft+nCols-1)),
@@ -77,11 +84,10 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 			)
 		fromto1 <- rbind(fromto1,meridianFromLeft,meridianFromRight)
 	}
-	else{}
+
 	fromto <- subset(fromto1,fromto1[,2] %in% toCells)
 
-	if(directions > 4)
-	{
+	if (directions > 4)	{
 		bishop <- as.integer(c(-nCols-1, -nCols+1, nCols-1,+nCols+1))
 		
 		coreFromToBishop <- .cs(fromCellsCore,bishop)
@@ -96,8 +102,7 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 
 		fromto2 <- rbind(coreFromToBishop,upperFromToBishop,lowerFromToBishop,leftFromToBishop,rightFromToBishop,upperleftFromToBishop,upperrightFromToBishop,lowerleftFromToBishop,lowerrightFromToBishop)
 		
-		if (outerMeridianConnect) 
-		{
+		if (outerMeridianConnect) {
 			meridianFromLeft <- rbind(
 				.cs(fromCellsLeft,c(2*nCols-1,-1)),
 				cbind(fromCellUpperleft,as.integer(fromCellUpperleft+2*nCols-1)),
@@ -110,13 +115,12 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 				)
 			fromto2 <- rbind(fromto2,meridianFromLeft,meridianFromRight)
 		}
-		else{}
+
 		fromto2 <- subset(fromto2,fromto2[,2] %in% toCells)
 		fromto <- rbind(fromto,fromto2)
 	}
-	else{}
-	if(directions > 8)
-	{
+
+	if (directions > 8) {
 
 		leftOuter <- seq(2*nCols+1,nCells-3*nCols+1,by=nCols) 
 		rightOuter <- seq(3*nCols,nCells-2*nCols,by=nCols)
@@ -204,8 +208,7 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 		fromto3 <- rbind(coreInnerFromToKnight, upperInnerFromToKnight, lowerInnerFromToKnight, leftInnerFromToKnight, rightInnerFromToKnight, upperleftInnerFromToKnight, upperrightInnerFromToKnight, lowerleftInnerFromToKnight, lowerrightInnerFromToKnight, leftOuterFromToKnight, rightOuterFromToKnight, upperOuterFromToKnight,	lowerOuterFromToKnight, upperleftUnderFromToKnight, upperrightLeftFromToKnight,	lowerleftUpFromToKnight, lowerrightUpFromToKnight, upperleftRightFromToKnight, upperrightUnderFromToKnight, lowerleftRightFromToKnight, lowerrightLeftFromToKnight, upperleftFromToKnight, upperrightFromToKnight, lowerleftFromToKnight, lowerrightFromToKnight)
 		fromto3 <- subset(fromto3,fromto3[,2] %in% toCells)
 		
-		if (outerMeridianConnect) 
-		{
+		if (outerMeridianConnect) {
 			knightLeft <- c(-nCols-1, -2, +2*nCols-2, 3*nCols-1)
 			knightRight <- c(-3*nCols+1, -2*nCols+2, +2, nCols+1)
 
@@ -236,16 +239,17 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 			
 			fromto3 <- rbind(fromto3, leftInnerFromToKnight, rightInnerFromToKnight, upperleftInnerFromToKnight, upperrightInnerFromToKnight, lowerleftInnerFromToKnight, lowerrightInnerFromToKnight, leftOuterFromToKnight, rightOuterFromToKnight, upperleftUnderFromToKnight, upperrightLeftFromToKnight, lowerleftUpFromToKnight, lowerrightUpFromToKnight, upperleftRightFromToKnight, upperrightUnderFromToKnight, lowerleftRightFromToKnight, lowerrightLeftFromToKnight, upperleftFromToKnight, upperrightFromToKnight, lowerleftFromToKnight, lowerrightFromToKnight)
 		}
-		else{}
 		
 		fromto3 <- subset(fromto3,fromto3[,2] %in% toCells)	
 		fromto <- rbind(fromto,fromto3)
 	}
-	else{}
+
 	colnames(fromto) <- c("from","to")
 	return(fromto)
 }
 
+
+
 .adjBishop <- function(raster, fromCells, toCells, outerMeridianConnect)  {
 	nCols <- ncol(raster)
 	nCells <- ncell(raster)
@@ -283,8 +287,7 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 
 	fromto <- rbind(coreFromToBishop,upperFromToBishop,lowerFromToBishop,leftFromToBishop,rightFromToBishop,upperleftFromToBishop,upperrightFromToBishop,lowerleftFromToBishop,lowerrightFromToBishop)
 	
-	if (outerMeridianConnect) 
-	{
+	if (outerMeridianConnect) {
 		meridianFromLeft <- rbind(
 			.cs(fromCellsLeft,c(2*nCols-1,-1)),
 			cbind(fromCellUpperleft,as.integer(fromCellUpperleft+2*nCols-1)),
@@ -297,7 +300,7 @@ adjacency <- function(raster, fromCells, toCells, directions) {
 			)
 		fromto <- rbind(fromto,meridianFromLeft,meridianFromRight)
 	}
-	else{}
 	fromto <- subset(fromto,fromto[,2] %in% toCells)
 	return(fromto)
 }
+
