@@ -93,7 +93,7 @@ setMethod('brick', signature(x='RasterStack'),
 		
 		if (values) {
 			
-			b@layernames <- x@layernames[1:nl]
+			b@data@names <- names(x)[1:nl]
 			if (canProcessInMemory(b, nl*2)) {
 				b <- setValues( b, getValues(x)[,1:nl]) 
 				if (any(is.factor(x))) {
@@ -130,7 +130,9 @@ setMethod('brick', signature(x='RasterStack'),
 
 setMethod('brick', signature(x='RasterBrick'), 
 	function(x, nl, ...){
-		if (missing(nl)) { nl <- nlayers(x) }
+		if (missing(nl)) { 
+			nl <- nlayers(x) 
+		}
 		e <- x@extent
 		b <- brick(xmn=e@xmin, xmx=e@xmax, ymn=e@ymin, ymx=e@ymax, nrows=x@nrows, ncols=x@ncols, crs=projection(x))
 		b@data@nlayers <- as.integer(nl)
@@ -189,7 +191,7 @@ setMethod('brick', signature(x='SpatialGrid'),
 			}
 			
 			b <- setValues(b, as.matrix(x))
-			b@layernames <- colnames(x)
+			b@data@names <- colnames(x)
 		}
 		return(b)
 	}	
