@@ -40,3 +40,37 @@ setMethod('freq', signature(x='RasterLayer'),
 	}
 )
 
+
+
+setMethod('freq', signature(x='RasterStackBrick'), 
+	function(x, digits=0, useNA="ifany", merge=FALSE, progress='', ...) {
+		
+		nl <- nlayers(x)
+		res <- list()
+		
+		pb <- pbCreate(nl, progress=progress)	
+		for (i in 1:nl) { 
+			res[[i]] <- freq( raster(x, i), useNA=useNA, progress='', ...) 
+			pbStep(pb, i)
+		}
+		pbClose(pb)
+		
+		names(res) <- ln <- names(x)
+		
+		if (merge) {
+			r <- res[[1]]
+			colnames(r)[2] <- ln[1]
+			if (nl > 1) {			
+				for (i in 2:nl) {
+					x <- res[[i]]
+					colnames(x)[2] <- ln[i]
+					r <- merge(r, x, by=1, all=TRUE)
+				}
+			}
+			return(r)
+		}
+		
+		return(res)
+	}
+)
+
