@@ -14,7 +14,7 @@
 
 .gdalWriteFormats <- function() {
 	gd <- gdalDrivers()
-	gd <- as.matrix(subset(gd, gd[,3] == T))
+	gd <- as.matrix( gd[gd[,3] == T, ] )
 	i <- which(gd[,1] %in% c('VRT', 'MEM', 'MFF', 'MFF2'))
 	gd[-i,]
 }
