@@ -21,7 +21,9 @@
 
 .couldBeLonLat <- function(x, warnings=TRUE) {
 	crsLL <- isLonLat(x)
-	if (class(x) == 'character') { return(crsLL) }
+	if (class(x) == 'character') { 
+		return(crsLL) 
+	}
 	crsNA <- projection(x)=='NA'
 	e <- extent(x)
 	extLL <- (e@xmin > -365 & e@xmax < 365 & e@ymin > -90.1 & e@ymax < 90.1) 
