@@ -6,11 +6,12 @@
 
 setMethod("Math", signature(x='Raster'),
     function(x){ 
-		funname <- as.character(sys.call(sys.parent())[[1]])
-		
+
 		if (!hasValues(x)) {
 			return(x)
 		}
+		funname <- as.character(sys.call(sys.parent())[[1]])
+		
 		
 		nl <- nlayers(x)
 		if (nl > 1) {
@@ -89,6 +90,25 @@ setMethod("Math", signature(x='Raster'),
 )
 
 
+
+setMethod("Math", signature(x='RasterLayerSparse'),
+    function(x){ 
+
+		if (!hasValues(x)) {
+			return(x)
+		}
+		funname <- as.character(sys.call(sys.parent())[[1]])
+
+		if (substr(funname, 1, 3) == 'cum' ) { 
+			setValues(x, do.call(funname, list(x@data@values)))
+		} else {
+			setValues(x, callGeneric(x@data@values))
+		}
+	}
+)
+
+
+
 setMethod("Math2", signature(x='Raster'), 
 	function (x, digits=0) {
 		digits <- max(0, digits)
