@@ -27,7 +27,22 @@ setMethod('merge', signature(x='Extent', y='ANY'),
 )
 
 
+setMethod('merge', signature(x='RasterStackBrick', y='missing'), 
+	function(x, ..., tolerance=0.05, filename="", ext=NULL) {
+		nl <- nlayers(x)
+		if (nl < 2) {
+			return(x)
+		} else if (nl == 2) {
+			merge(x[[1]], x[[2]], tolerance=tolerance, filename=filename, overlap=TRUE, ext=ext)
+		} else {
+			do.call(merge, c(x=x[[1]], y=x[[2]], .makeRasterList(x[[3:nl]]), tolerance=tolerance, filename=filename, overlap=TRUE, ext=ext))
+		}
+	}
+)
+
+
 setMethod('merge', signature(x='Raster', y='Raster'), 
+
 function(x, y, ..., tolerance=0.05, filename="", overlap=TRUE, ext=NULL) { 
 	x <- c(x, y, list(...))	
 	isRast <- sapply(x, function(x) inherits(x, 'Raster'))
