@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  June 2008
 # Version 1.0
 # Licence GPL v3
@@ -6,8 +6,16 @@
 
 'NAvalue<-' <- function(x, value) {
 	if (inherits(x, 'RasterStack')) {
-		for (i in 1:nlayers(x)) {
-			x@layers[[i]]@file@nodatavalue <- value[[1]]
+		nl <- nlayers(x)
+		if (length(value) == 1) {
+			value <- rep(value[[1]], nl)
+		} else {
+			v <- vector(length=nl)
+			v[] <- as.vector(value)
+			value <- v
+		}
+		for (i in 1:nl) {
+			x@layers[[i]]@file@nodatavalue <- value[i]
 		}
 	} else {
 		x@file@nodatavalue <- value[[1]]
@@ -15,7 +23,7 @@
 	return(x)
 }
 
-'NAvalue' <- function(x, value) {
+NAvalue <- function(x) {
 	if (inherits(x, 'RasterStack')) {
 		sapply(x@layers, function(x) { x@file@nodatavalue })
 	} else {
