@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date:  October 2008
 # Version 0.9
 # Licence GPL v3
@@ -17,6 +17,7 @@
 	x
 }
 
+
 .goodNames <- function(ln, prefix='layer') {
 	ln <- trim(as.character(ln))
 	ln[is.na(ln)] <- ""
@@ -30,21 +31,30 @@
 
 setMethod('names', signature(x='Raster'), 
 	function(x) { 
-		ln <- x@layernames
+		if (.hasSlot(x@data, 'names')) {
+			ln <- x@data@names
+		} else {
+			ln <- x@layernames		
+		}
+		ln <- ln[1:nlayers(x)]
+		.goodNames(as.vector(ln))
+	}
+)
+
+
+setMethod('names', signature(x='RasterStack'), 
+	function(x) { 
+		ln <- sapply(x@layers, function(i) i@data@names)
 		ln <- ln[1:nlayers(x)]
 		.goodNames(as.vector(ln))
 	}
 )
 
 layerNames <- function(x) {
-	ln <- x@layernames
-	ln <- ln[1:nlayers(x)]
-	.goodNames(as.vector(ln))
+	names(x)
 }
 
 
-
-
 setMethod('names<-', signature(x='Raster'), 
 	function(x, value)  {
 		'layerNames<-'(x, value)
@@ -53,24 +63,33 @@ setMethod('names<-', signature(x='Raster'),
 
 
 'layerNames<-' <- function(x, value) {
+
 	nl <- nlayers(x)
 	if (is.null(value)) {
 		value <- rep('', nl)
 	} else if (length(value) != nl) {
 		stop('incorrect number of layer names')
 	}
-	x@layernames <- .goodNames(value)
+	value <- .goodNames(value)
 	
-	# the below is good, but very very slow for objects with many layers
-	#if (inherits(x, 'RasterStack')){
-	#	for (i in 1:nl) {
-	#		x@layers[[i]]@layernames <- x@layernames[i]
-	#	}
-	#}
+	if (inherits(x, 'RasterStack')){
+		
+		x@layers <- sapply(1:nl, function(i){ 
+			r <- x@layers[[i]]
+			r@data@names <- value[i]
+			r
+		})
+		
+	} else {
+		if (.hasSlot(x@data, 'names')) {
+			x@data@names <- value
+		} else {
+			x@layernames <- value		
+		}
+	}
+
 	return(x)
 }
 
 
 
-
-
