@@ -11,9 +11,15 @@ setMethod ('print', 'Raster',
 			show(x)
 		} else {
 			if (x@file@driver == 'netcdf') {
-				nc <- open.ncdf(x@file@name)
-				print(nc)
-				close.ncdf(nc)
+				if (getOption('rasterNCDF4')) {
+					nc <- ncdf4::nc_open(x@file@name)
+					print(nc)
+					ncdf4::nc_close(nc)
+				} else {
+					nc <- open.ncdf(x@file@name)
+					print(nc)
+					close.ncdf(nc)
+				}
 			} else if (any(is.factor(x))) {
 				cat('factor levels (value attributes)\n')
 				f <- x@data@attributes
@@ -72,7 +78,7 @@ setMethod ('print' , 'Spatial',
 		}
 		
 		e <- bbox(x)
-		cat('extent      : ' , e[1], ', ', e[2], ', ', e[3], ', ', e[4], '  (xmin, xmax, ymin, ymax)\n', sep="")
+		cat('extent      : ' , e[1,1], ', ', e[1,2], ', ', e[2,1], ', ', e[2,2], '  (xmin, xmax, ymin, ymax)\n', sep="")
 		cat('coord. ref. :' , projection(x, TRUE), '\n')
 		
 		
