@@ -44,19 +44,14 @@ setMethod ('show' , 'RasterLayer',
 		if (hasValues(object)) {
 			fd <- object@data@fromdisk
 			if (fd) {
-				cat('values      :', filename(object), '\n')
+				cat('data source :', filename(object), '\n')
 			} else {
-				cat('values      : in memory\n')			
+				cat('data source : in memory\n')			
 			}
-				
-			cat('layer name  :', names(object), '\n')
-			
+			cat('names       :', names(object), '\n')
 			if (object@data@haveminmax) {
-				cat('min value   :' , minValue(object), '\n')
-				cat('max value   :' , maxValue(object), '\n')
+				cat('values      : ', minValue(object), ', ',  maxValue(object), '  (min, max)\n', sep="")
 			}
-		} else {
-			cat('values      : none\n')			
 		}
 
 
@@ -90,7 +85,7 @@ setMethod ('show' , 'RasterLayer',
 				name <- names(object@z)
 				if (is.null(name)) name <- 'z-value'
 				name <- paste(sprintf("%-12s", name), ':', sep='')
-				cat(name, z[1], '\n')
+				cat(name, as.character(z[1]), '\n')
 			}
 
 			if (object@file@driver == 'netcdf') {
@@ -132,12 +127,12 @@ setMethod ('show' , 'RasterBrick',
 		if (hasValues(object)) {
 			fd <- object@data@fromdisk
 			if (fd) {
-				cat('values      :', filename(object), '\n')
+				cat('data source :', filename(object), '\n')
 			} else {
-				cat('values      : in memory\n')			
+				cat('data source : in memory\n')			
 			}
 			
-			cat('layer names :', paste(ln, collapse=', '), '\n')
+			cat('names       :', paste(ln, collapse=', '), '\n')
 
 			if (object@data@haveminmax) {
 				minv <- format(minValue(object), digits=2)
@@ -155,9 +150,7 @@ setMethod ('show' , 'RasterBrick',
 #				minv <- rep('?', min(nl, 10))
 #				maxv <- rep('?', min(nl, 10))
 			}
-		} else {
-			cat('values      : none\n')			
-		}
+		} 
 
 		z <- getZ(object)
 		if (length(z) > 0) {
@@ -165,9 +158,9 @@ setMethod ('show' , 'RasterBrick',
 			if (is.null(name)) name <- 'z-value'
 			name <- paste(sprintf("%-12s", name), ':', sep='')
 			if (length(z) < mnr) {
-				cat(name, paste(z, collapse=', '), '\n')
+				cat(name, paste(as.character(z), collapse=', '), '\n')
 			} else {
-				cat(name, paste(range(z), collapse=', '), '(min, max)\n')
+				cat(name, paste(as.character(range(z)), collapse=', '), '(min, max)\n')
 			}
 		}
 		
@@ -213,7 +206,7 @@ setMethod ('show' , 'RasterStack',
 			if (nl > mnr) {
 				ln <- c(ln[1:mnr], '...')
 			}
-			cat('layer names :', paste(ln, collapse=', '), '\n')
+			cat('names       :', paste(ln, collapse=', '), '\n')
 			
 			minv <- format(minValue(object), digits=2)
 			maxv <- format(maxValue(object), digits=2)
@@ -236,10 +229,10 @@ setMethod ('show' , 'RasterStack',
 			if (name == '') name <- 'z-value'
 			name <- paste(sprintf("%-12s", name), ':', sep='')
 			if (length(z) < mnr) {
-				cat(name, paste(z, collapse=', '), '\n')
+				cat(name, paste(as.character(z), collapse=', '), '\n')
 			} else {
 				z <- range(z)
-				cat(name, paste(z, collapse=' - '), '(range)\n')
+				cat(name, paste(as.character(z), collapse=' - '), '(range)\n')
 			}
 		}
 		
