@@ -7,7 +7,11 @@
 stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 
 	nl <- nlayers(x)
-	if (nl == 1) { 	makemat <- TRUE	} else { makemat <- FALSE  }
+	if (nl == 1) { 	
+		makemat <- TRUE	
+	} else { 
+		makemat <- FALSE  
+	}
 	
 	
 	ind <- vector(length=nl)
@@ -25,64 +29,54 @@ stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 
 	filename <- trim(filename)
 
-	fun <- .makeTextFun(fun)
+	rowcalc <- FALSE
+	fun <- raster:::.makeTextFun(fun)
 	if (class(fun) == 'character') { 
 		rowcalc <- TRUE 
-		fun <- .getRowFun(fun)
-	} else { rowcalc <- FALSE  	}
-	
+		fun <- raster:::.getRowFun(fun)
+	} 
 	
 	if (canProcessInMemory(out, nl+nlout)) {
-		v <- matrix(NA, nrow=ncell(out), ncol=nlout)
-		a <- getValues(x)
-		if (makemat) { a < - matrix(a, ncol=1) }
-
-		pb <- pbCreate(length(uin), ...)
-
-		if (rowcalc) {
-			for (j in uin) {
-				k <- which(ind == j)
-				v[, j] <- fun(a[ , k, drop=FALSE], na.rm=na.rm)
-				pbStep(pb)
-			}
-		} else {
-			for (j in uin) {
-				k <- which(ind == j)
-				v[, j] <- apply(a[ , k, drop=FALSE], 1, fun, na.rm=na.rm)
-				pbStep(pb)
-			}
+		x <- getValues(x)
+		if (makemat) { 
+			x <- matrix(x, ncol=1) 
 		}
+		pb <- pbCreate(3,...)
+		pbStep(pb)
+		if (rowcalc) {
+			v <- lapply(uin, function(i) fun(x[, ind==uin[i], drop=FALSE], na.rm=na.rm))
+		} else {
+			v <- lapply(uin, function(i, ...) apply(x[, ind==uin[i], drop=FALSE], 1, fun, na.rm=na.rm))
+		}
+		pbStep(pb)		
+		v <- do.call(cbind, v)
 		out <- setValues(out, v)
 		if (filename != "") {
 			out <- writeRaster(out, filename=filename, ...)
 		}
+		pbStep(pb)
 		pbClose(pb)
 		return(out)
 	}
-	
+
 	if (filename == '') { filename <- rasterTmpFile() } 
 	
 	out <- writeStart(out, filename=filename, ...)
 	tr <- blockSize(out, n=nl+nlout)
 	pb <- pbCreate(tr$n, ...)
 
-	v <- matrix(nrow=tr$nrows[1] * out@ncols, ncol=nlout)
 	for (i in 1:tr$n) {
 		a <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
-		if (makemat) { a < - matrix(a, ncol=1) }
-		if (i == tr$n) { v <- matrix(nrow=tr$nrows[i] * out@ncols, ncol=nlout) }
+		if (makemat) { 
+			a <- matrix(a, ncol=1) 
+		}
 
 		if (rowcalc) {
-			for (j in uin) {
-				k <- which(ind == j)
-				v[,j] <- fun(a[,k,drop=FALSE], na.rm=na.rm)
-			}
+			v <- lapply(uin, function(i) fun(a[, ind==uin[i], drop=FALSE], na.rm=na.rm))
 		} else {
-			for (j in uin) {
-				k <- which(ind == j)
-				v[,j] <- apply(a[,k,drop=FALSE], 1, fun, na.rm=na.rm)
-			}
+			v <- lapply(uin, function(i, ...) apply(a[, ind==uin[i], drop=FALSE], 1, fun, na.rm=na.rm))
 		}
+		v <- do.call(cbind, v)
 		out <- writeValues(out, v, tr$row[i])
 		pbStep(pb) 
 	}
@@ -93,3 +87,4 @@ stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 }
 	
 
+
