@@ -1,5 +1,4 @@
 # Author: Robert J. Hijmans
-# contact: r.hijmans@gmail.com
 # Date : January 2009
 # Version 0.9
 # Licence GPL v3
@@ -8,11 +7,15 @@
 .writeGDALall <- function(x, filename, options=NULL, ...) {
 	if (nlayers(x) > 1) {
 		y <- brick(x, values=FALSE)
+		x <- getValues(x)
+		stat <- t(apply(x, 2, function(z, ...) cbind(mean(z, na.rm=TRUE), sd(z, na.rm=TRUE))))
 	} else {
 		y <- raster(x)
+		x <- getValues(x)
+		stat <- cbind(mean(x, na.rm=TRUE), sd(x, na.rm=TRUE))
 	}
 	y <- .startGDALwriting(y, filename, options, ...)
-	y <- writeValues(y, values(x), start=1)
-	.stopGDALwriting(y)
+	x <- writeValues(y, x, start=1)
+	.stopGDALwriting(x, stat)
 }
 	
