@@ -4,7 +4,7 @@
 	pkg.info <- utils::packageDescription('raster') 
 	packageStartupMessage(paste("raster ", pkg.info[["Version"]], " (", pkg.info["Date"], ")", sep=""))
 
-	tst <- try( removeTmpFiles(), silent=TRUE )
+	tst <- try( removeTmpFiles( .tmptime() ), silent=TRUE ) 
 	return(invisible(0))
 }
 
